@@ -1,10 +1,11 @@
 from django.conf.urls import url
 
 from NEMO.apps.area_access import views
+from NEMO.views import area_access
 
 urlpatterns = [
 	# Tablet area access
-	url(r'^occupancy/$', views.area_access_occupancy, name='area_access_occupancy'),
+	url(r'^occupancy/$', area_access.occupancy, name='area_access_occupancy'),
 	url(r'^welcome_screen/(?P<door_id>\d+)/$', views.welcome_screen, name='welcome_screen'),
 	url(r'^farewell_screen/(?P<door_id>\d+)/$', views.farewell_screen, name='farewell_screen'),
 	url(r'^login_to_area/(?P<door_id>\d+)/$', views.login_to_area, name='login_to_area'),
