@@ -8,31 +8,23 @@ from django.utils import timezone
 from django.utils.formats import localize
 from django.views.decorators.http import require_GET, require_POST
 
+from NEMO.decorators import postpone
 from NEMO.exceptions import (
 	InactiveUserError,
-	NoActiveProjectsForUserError,
-	PhysicalAccessExpiredUserError,
-	NoPhysicalAccessUserError,
-	NoAccessiblePhysicalAccessUserError,
-	UnavailableResourcesUserError,
 	MaximumCapacityReachedError,
+	NoAccessiblePhysicalAccessUserError,
+	NoActiveProjectsForUserError,
+	NoPhysicalAccessUserError,
+	PhysicalAccessExpiredUserError,
+	ProjectChargeException,
 	ReservationRequiredUserError,
 	ScheduledOutageInProgressError,
-	ProjectChargeException,
+	UnavailableResourcesUserError,
 )
-from NEMO.models import (
-	Door,
-	PhysicalAccessLog,
-	PhysicalAccessType,
-	Project,
-	User,
-	UsageEvent,
-	BadgeReader,
-)
-from NEMO.tasks import postpone
-from NEMO.views.area_access import log_out_user, log_in_user_to_area
+from NEMO.models import (BadgeReader, Door, PhysicalAccessLog, PhysicalAccessType, Project, UsageEvent, User)
+from NEMO.views.area_access import log_in_user_to_area, log_out_user
 from NEMO.views.customization import get_customization
-from NEMO.views.policy import check_policy_to_enter_this_area, check_policy_to_enter_any_area, check_billing_to_project
+from NEMO.views.policy import check_billing_to_project, check_policy_to_enter_any_area, check_policy_to_enter_this_area
 from NEMO.views.tool_control import interlock_bypass_allowed
 
 
@@ -66,14 +58,13 @@ def farewell_screen(request, door_id):
 def login_to_area(request, door_id):
 	door = get_object_or_404(Door, id=door_id)
 
-	badge_number = request.POST.get("badge_number", "")
+	badge_number = request.POST.get("badge_number")
 	bypass_interlock = request.POST.get("bypass", 'False') == 'True'
-	if badge_number == "":
+	if not badge_number:
 		return render(request, "area_access/badge_not_found.html")
 	try:
-		badge_number = int(badge_number)
 		user = User.objects.get(badge_number=badge_number)
-	except (User.DoesNotExist, ValueError):
+	except User.DoesNotExist:
 		return render(request, "area_access/badge_not_found.html")
 
 	log = PhysicalAccessLog()
@@ -239,10 +230,12 @@ def delay_lock_door(door_id):
 @permission_required("NEMO.change_areaaccessrecord")
 @require_POST
 def logout_of_area(request, door_id):
+	badge_number = request.POST.get("badge_number")
+	if not badge_number:
+		return render(request, "area_access/badge_not_found.html")
 	try:
-		badge_number = int(request.POST.get("badge_number", ""))
 		user = User.objects.get(badge_number=badge_number)
-	except (User.DoesNotExist, ValueError):
+	except User.DoesNotExist:
 		return render(request, "area_access/badge_not_found.html")
 	record = user.area_access_record()
 	if record:
@@ -271,11 +264,12 @@ def logout_of_area(request, door_id):
 @require_POST
 def open_door(request, door_id):
 	door = get_object_or_404(Door, id=door_id)
-	badge_number = request.POST.get("badge_number", "")
+	badge_number = request.POST.get("badge_number")
+	if not badge_number:
+		return render(request, "area_access/badge_not_found.html")
 	try:
-		badge_number = int(badge_number)
 		user = User.objects.get(badge_number=badge_number)
-	except (User.DoesNotExist, ValueError):
+	except User.DoesNotExist:
 		return render(request, "area_access/badge_not_found.html")
 	if user.area_access_record() and user.area_access_record().area == door.area:
 		log = PhysicalAccessLog(
