@@ -1,14 +1,13 @@
-from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.auth.decorators import login_required
 from django.http import JsonResponse
-from django.shortcuts import render, get_object_or_404
+from django.shortcuts import get_object_or_404, render
 from django.views.decorators.http import require_GET
 
+from NEMO.decorators import staff_member_or_tool_superuser_required, staff_member_required
 from NEMO.models import User
-from NEMO.tasks import staff_member_or_tool_superuser_required
 
 
-@staff_member_or_tool_superuser_required(login_url=None)
+@staff_member_or_tool_superuser_required
 @require_GET
 def get_projects(request):
 	""" Gets a list of all active projects for a specific user. This is only accessible by staff members. """
@@ -21,7 +20,7 @@ def get_projects(request):
 	return JsonResponse(dict(projects=list(projects.values('id', 'name'))))
 
 
-@staff_member_required(login_url=None)
+@staff_member_required
 @require_GET
 def get_projects_for_tool_control(request):
 	user_id = request.GET.get('user_id')
